#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 GraphSCC
version:              1.0.4
visibility:           public
id:                   GraphSCC-1.0.4-Ftfb7WNmBIa96KNftUSJsu
key:                  GraphSCC-1.0.4-Ftfb7WNmBIa96KNftUSJsu
license:              BSD-3-Clause
maintainer:           diatchki@galois.com
author:               Iavor S. Diatchki
synopsis:
    Tarjan'\''s algorithm for computing the strongly connected components of a graph.

description:
    Tarjan'\''s algorithm for computing the strongly connected components of a graph.

category:             Algorithms
abi:                  fe94f03202fea9ed39ea619ee4963f99
exposed:              True
exposed-modules:      Data.Graph.SCC
hidden-modules:       Data.Graph.ArraySCC
import-dirs:          /usr/lib/ghc-9.6.6/site-local/GraphSCC-1.0.4
library-dirs:         /usr/lib/ghc-9.6.6/site-local/GraphSCC-1.0.4
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/GraphSCC-1.0.4
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-graphscc
hs-libraries:         HSGraphSCC-1.0.4-Ftfb7WNmBIa96KNftUSJsu
depends:              array-0.5.6.0 base-4.18.2.1 containers-0.6.7
haddock-interfaces:   /usr/share/doc/haskell-graphscc/html/GraphSCC.haddock
haddock-html:         /usr/share/doc/haskell-graphscc/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

